#
# spec file for package python-mechanize
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname mechanize
%{?sle15_python_module_pythons}
Name:           python-mechanize
Version:        0.4.9
Release:        1.1
Summary:        Stateful programmatic web browsing
License:        BSD-3-Clause AND (BSD-3-Clause OR ZPL-2.1)
URL:            https://github.com/python-mechanize/mechanize
Source:         https://files.pythonhosted.org/packages/source/m/mechanize/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module Twisted}
BuildRequires:  %{python_module html5lib}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-html5lib
BuildArch:      noarch
%python_subpackages

%description
Stateful programmatic web browsing in Python. Browse pages
programmatically with HTML form filling and clicking
of links.

%prep
%autosetup -p1 -n %{modname}-%{version}
sed -i -e '1{/^#!\/usr\/bin\/env python/d}' %{modname}/{_entities,_equiv,_form_controls,polyglot}.py
sed -i -e '1{/^#!/d}' examples/forms/{echo.cgi,example.py,simple.py}
chmod -x examples/forms/{echo.cgi,example.py,simple.py}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand $python ./run_tests.py -v

%files %{python_files}
%license LICENSE
%doc examples README.rst
%{python_sitelib}/%{modname}
%{python_sitelib}/%{modname}-%{version}*-info

%changelog
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.4.9:
  * Fix error on PyPy3
  * Fix error CPython 3.12
- drop python-mechanize-setup.cfg.patch,
  support-python-311.patch: upstream
* Tue Jun 27 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Mar 31 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-python-311.patch:
  * http.cookiejar changed behaviour from Python 3.11 onwards, support
    both.
* Tue Oct 11 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on python.
* Mon Aug  1 2022 Ben Greiner <code@bnavigator.de>
- Reference upstream patch in specfile for future updates
- Remove catchall in files section that would have found the
  mistake
- Update shebang fix commands
- Fix requirements
- Update description
* Sun Jul 31 2022 ecsos <ecsos@opensuse.org>
- Add python-mechanize-setup.cfg.patch to fix mechanize not
  found during build. (boo#1202003)
* Sun Jul 24 2022 Dirk Müller <dmueller@suse.com>
- update to 0.4.8:
  * Handle mal-encoded robots.txt files more gracefully
  * Support HTTP 308 redirects
* Mon Jan 24 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.4.7 (bsc#1207242, CVE-2021-32837):
  * Fix the ~ character being percent escaped when sending URLs to servers.
  * Python 3.10 compatibility
  * Fix a bug in the regex used to parse www-authenticate headers that could
    lead to Denial-of-Service
* Wed Jan 22 2020 Martin Sirringhaus <martin.sirringhaus@suse.com>
- Update to 0.4.5:
  * Add a set_html() method to the browser object
- Update to 0.4.4:
  * URLs passed into mechanize now automatically have URL unsafe
    characters percent encoded. This is necessary because newer
    versions of python disallow processing of URLs with unsafe
    characters. Note that this means values return by
    get_full_url(), get_selector() etc will be percent encoded.
* Tue Nov 12 2019 Bogdano Arendartchuk <BArendartchuk@suse.com>
- added missing dependencies: Twisted, zope.interface and html5lib
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.3:
  * When filling forms with unicode strings automatically encode them into
    the correct encoding fr the HTML page being viewed
  * Guess content type when uploading files if not specified
  * py3 compat - Have the version of simple cookies be 0 rather than None
* Fri May 17 2019 Meera Belur <mbelur@suse.com>
- Update to v0.4.2
  * A couple of python 3 specific fixes for proxy authorization and
    adding controls to forms
* Fri Apr  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.1:
  * A couple of python 3 specific fixes for servers with misisng robots.txt
    files and also errors when using basic/digest auth
* Fri Jan 18 2019 mcepl@suse.com
- Upgrade to 0.4.0:
  * Python 3 compatibility
  * Add a finalize_request_headers callback to Browser to allow
    users full control of what headers are sent with every
    request
  * Preserve header ordering when making HTTP requests
  * Fix processing of http-equiv meta tags incorrectly lower casing
    the content
  * Fix error when a textbox contained within a form contains
    unicode characters
- Add missing BR for testing (Twisted and zope.interface)
* Wed Aug 29 2018 tchvatal@suse.com
- Require full python2 as it needs SSL module
* Mon Aug  6 2018 toddrme2178@gmail.com
- Remove unneeded dependencies.
* Thu Jun 14 2018 mcepl@suse.com
- Clean SPEC file (only py2k, but tests are enabled and run)
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Sat Nov  9 2013 p.drouand@gmail.com
- Fix changes file by removing name of committer
- Fix Group : Development/Libraries/Python > Development/Languages/Python
* Sat Nov  9 2013 saigkill@opensuse.org
- changed BR python-clientform to python-ClientForm (now it matches)
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Mar 12 2012 saschpe@gmx.de
- Simplified macro usage
* Wed Sep 21 2011 saschpe@suse.de
- Set license to "(BSD-3-Clause or ZPL-2.1) and BSD-3-Clause", bnc#719310
* Tue Sep 20 2011 saschpe@suse.de
- Update to version 0.2.5:
  * This is essentially a no-changes release to fix easy_install
    breakage caused by a SourceForge issue
  * Sourceforge is returning invalid HTTP responses, make download
    links point to PyPI instead
  * Include cookietest.cgi in source distribution
  * Note new IETF cookie standardisation effort
- Fixed doc-file-dependency rpmlint issue
* Fri Oct 29 2010 rwobben@hotmail.com
- update to version 0.2.4
  * Fix IndexError on empty Content-type header value. (GH-18)
  * Fall back to another encoding if an unknown one is declared.
    Fixes traceback on unknoqn encoding in Content-type header. (GH-30)
- additional changes from version 0.2.3
  * Fix str(ParseError()) traceback. (GH-25)
  * Add equality methods to mechanize.Cookie . (GH-29)
- additional changes from version 0.2.2
  * Officially support Python 2.7 (no changes were required)
  * Fix TypeError on .open()ing ftp: URL (only affects Python 2.4
    and 2.5)
  * Don't include HTTPSHandler in __all__ if it's not available
- additional changes from version 0.2.0
  * Behaviour change: merged upstream urllib2 change (allegedly a
    "bug fix") to return a response for all 2** HTTP responses (e.g.
    206 Partial Content).  Previously, only 200 caused a response
    object to be returned.  All other HTTP response codes resulted
    in a response object being raised as an exception.
  * Behaviour change: Use of mechanize classes with `urllib2` (and
    vice-versa) is no longer supported.  However, existing classes
    implementing the urllib2 Handler interface are likely to work
    unchanged with mechanize.  Removed RequestUpgradeProcessor,
    ResponseUpgradeProcessor, SeekableProcessor.
  * ClientForm has been merged into mechanize.  This means that
    mechanize has no dependencies other than Python itself.  The
    ClientForm API is still available -- to switch from ClientForm to
    mechanize, just s/ClientForm/mechanize in your source code, and
    ensure any use of the module logging logger named "ClientForm" is
    updated to use the new logger name "mechanize.forms".  I probably
    won't do further standalone releases of ClientForm.
  for the remaining changes in 0.2.0 and 0.2.1 see
  /usr/share/doc/packages/python-mechanize/ChangeLog.txt
* Thu Jul  1 2010 toms@suse.de
- Added check for openSUSE 11.1 and build arch
* Thu Jul  1 2010 toms@suse.de
- Merging from my home repo:
  - updated to 0.1.11
  - Set buildarch to noarch
  - Extended changelog
  - Added rpmlintrc file
* Thu Jul  2 2009 toms@suse.de
- Removed provides (wrong package)
* Tue Jun 30 2009 toms@suse.de
- Added provides for python-ClientForm
* Sat Jun 13 2009 toms@suse.de
- Fixed package typo: python-clientform -> python-ClientForm.
  Thanks to Alfredo J. V. P.!
* Sat Feb 21 2009 toms@suse.de
- Update to 0.1.11
* Tue Feb 12 2008 poeml@suse.de
- update to 0.1.7b
* Fri Jan 19 2007 judas_iscariote@shorewall.net
- update
* Wed Aug 30 2006 jfunk@funktronics.ca
- Initial release
